@@ -5,6 +5,7 @@ import pandas as pd
 from flatbuffers.builder import np
 from sklearn.datasets import fetch_20newsgroups
 
+from chester.data_loader.webtext_data import load_data_pirates, load_data_king_arthur, load_data_chat_logs
 from chester.run.full_run import run_madcat
 from chester.run.user_classes import Data, ModelRun
 
@@ -12,17 +13,13 @@ matplotlib.use('TkAgg')
 target_column = 'target'
 
 ################################################################################################
-# df1 = load_data_pirates().assign(target='pirate')  # .sample(100, replace=True)
-# df2 = load_data_king_arthur().assign(target='arthur')  # .sample(100, replace=True)
-# df3 = load_data_chat_logs().assign(target='chat')  # .sample(100, replace=True)
-# df = pd.concat([df1, df2
-#                 , df3
-#                 ])
-# df['text_trimmed'] = df['text'].apply(lambda x: x[:100])
-# df.rename(columns={'text': 'text_a'}, inplace=True)
+df1 = load_data_pirates().assign(target='pirate').sample(200, replace=True)
+df2 = load_data_king_arthur().assign(target='arthur').sample(200, replace=True)
+df3 = load_data_chat_logs().assign(target='chat').sample(100, replace=True)
+df = pd.concat([df1, df2
+                   , df3
+                ])
 # df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
-
-
 ################################################################################################
 
 
